Pipecat Flows API Reference
===========================

Welcome to the Pipecat Flows API reference documentation!

Pipecat Flows is a conversation flow management add-on for Pipecat AI applications,
enabling sophisticated state-driven conversational experiences with conditional
logic, flow transitions, and context management.

Quick Links
-----------

* `GitHub Repository <https://github.com/pipecat-ai/pipecat-flows>`_
* `Main Pipecat Documentation <https://docs.pipecat.ai>`_

.. toctree::
   :maxdepth: 3
   :caption: API Reference
   :hidden:

   Actions <api/pipecat_flows.actions>
   Adapters <api/pipecat_flows.adapters>
   Exceptions <api/pipecat_flows.exceptions>
   Manager <api/pipecat_flows.manager>
   Types <api/pipecat_flows.types>